@@ -58,18 +58,18 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import projen
-import projen.awscdk
-import projen.cdk
-import projen.github
-import projen.github.workflows
-import projen.javascript
-import projen.release
-import projen.typescript
+import projen as _projen_04054675
+import projen.awscdk as _projen_awscdk_04054675
+import projen.cdk as _projen_cdk_04054675
+import projen.github as _projen_github_04054675
+import projen.github.workflows as _projen_github_workflows_04054675
+import projen.javascript as _projen_javascript_04054675
+import projen.release as _projen_release_04054675
+import projen.typescript as _projen_typescript_04054675
 
 
 class AwsCdkConstructLibrary(
-    projen.awscdk.AwsCdkConstructLibrary,
+    _projen_awscdk_04054675.AwsCdkConstructLibrary,
     metaclass=jsii.JSIIMeta,
     jsii_type="@pepperize/projen-awscdk-construct.AwsCdkConstructLibrary",
 ):
@@ -80,8 +80,8 @@ class AwsCdkConstructLibrary(
         integration_test_auto_discover: typing.Optional[builtins.bool] = None,
         lambda_auto_discover: typing.Optional[builtins.bool] = None,
         lambda_extension_auto_discover: typing.Optional[builtins.bool] = None,
-        lambda_options: typing.Optional[typing.Union[projen.awscdk.LambdaFunctionCommonOptions, typing.Dict[str, typing.Any]]] = None,
-        catalog: typing.Optional[typing.Union[projen.cdk.Catalog, typing.Dict[str, typing.Any]]] = None,
+        lambda_options: typing.Optional[typing.Union[_projen_awscdk_04054675.LambdaFunctionCommonOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        catalog: typing.Optional[typing.Union[_projen_cdk_04054675.Catalog, typing.Dict[builtins.str, typing.Any]]] = None,
         cdk_version: builtins.str,
         cdk_assert: typing.Optional[builtins.bool] = None,
         cdk_assertions: typing.Optional[builtins.bool] = None,
@@ -97,81 +97,81 @@ class AwsCdkConstructLibrary(
         compat_ignore: typing.Optional[builtins.str] = None,
         compress_assembly: typing.Optional[builtins.bool] = None,
         docgen_file_path: typing.Optional[builtins.str] = None,
-        dotnet: typing.Optional[typing.Union[projen.cdk.JsiiDotNetTarget, typing.Dict[str, typing.Any]]] = None,
+        dotnet: typing.Optional[typing.Union[_projen_cdk_04054675.JsiiDotNetTarget, typing.Dict[builtins.str, typing.Any]]] = None,
         exclude_typescript: typing.Optional[typing.Sequence[builtins.str]] = None,
-        publish_to_go: typing.Optional[typing.Union[projen.cdk.JsiiGoTarget, typing.Dict[str, typing.Any]]] = None,
-        publish_to_maven: typing.Optional[typing.Union[projen.cdk.JsiiJavaTarget, typing.Dict[str, typing.Any]]] = None,
-        publish_to_nuget: typing.Optional[typing.Union[projen.cdk.JsiiDotNetTarget, typing.Dict[str, typing.Any]]] = None,
-        publish_to_pypi: typing.Optional[typing.Union[projen.cdk.JsiiPythonTarget, typing.Dict[str, typing.Any]]] = None,
-        python: typing.Optional[typing.Union[projen.cdk.JsiiPythonTarget, typing.Dict[str, typing.Any]]] = None,
+        publish_to_go: typing.Optional[typing.Union[_projen_cdk_04054675.JsiiGoTarget, typing.Dict[builtins.str, typing.Any]]] = None,
+        publish_to_maven: typing.Optional[typing.Union[_projen_cdk_04054675.JsiiJavaTarget, typing.Dict[builtins.str, typing.Any]]] = None,
+        publish_to_nuget: typing.Optional[typing.Union[_projen_cdk_04054675.JsiiDotNetTarget, typing.Dict[builtins.str, typing.Any]]] = None,
+        publish_to_pypi: typing.Optional[typing.Union[_projen_cdk_04054675.JsiiPythonTarget, typing.Dict[builtins.str, typing.Any]]] = None,
+        python: typing.Optional[typing.Union[_projen_cdk_04054675.JsiiPythonTarget, typing.Dict[builtins.str, typing.Any]]] = None,
         rootdir: typing.Optional[builtins.str] = None,
         disable_tsconfig: typing.Optional[builtins.bool] = None,
         docgen: typing.Optional[builtins.bool] = None,
         docs_directory: typing.Optional[builtins.str] = None,
         entrypoint_types: typing.Optional[builtins.str] = None,
         eslint: typing.Optional[builtins.bool] = None,
-        eslint_options: typing.Optional[typing.Union[projen.javascript.EslintOptions, typing.Dict[str, typing.Any]]] = None,
+        eslint_options: typing.Optional[typing.Union[_projen_javascript_04054675.EslintOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         libdir: typing.Optional[builtins.str] = None,
         projenrc_ts: typing.Optional[builtins.bool] = None,
-        projenrc_ts_options: typing.Optional[typing.Union[projen.typescript.ProjenrcOptions, typing.Dict[str, typing.Any]]] = None,
+        projenrc_ts_options: typing.Optional[typing.Union[_projen_typescript_04054675.ProjenrcOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         sample_code: typing.Optional[builtins.bool] = None,
         srcdir: typing.Optional[builtins.str] = None,
         testdir: typing.Optional[builtins.str] = None,
-        tsconfig: typing.Optional[typing.Union[projen.javascript.TypescriptConfigOptions, typing.Dict[str, typing.Any]]] = None,
-        tsconfig_dev: typing.Optional[typing.Union[projen.javascript.TypescriptConfigOptions, typing.Dict[str, typing.Any]]] = None,
+        tsconfig: typing.Optional[typing.Union[_projen_javascript_04054675.TypescriptConfigOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        tsconfig_dev: typing.Optional[typing.Union[_projen_javascript_04054675.TypescriptConfigOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         tsconfig_dev_file: typing.Optional[builtins.str] = None,
         typescript_version: typing.Optional[builtins.str] = None,
         default_release_branch: builtins.str,
         artifacts_directory: typing.Optional[builtins.str] = None,
         auto_approve_upgrades: typing.Optional[builtins.bool] = None,
         build_workflow: typing.Optional[builtins.bool] = None,
-        build_workflow_triggers: typing.Optional[typing.Union[projen.github.workflows.Triggers, typing.Dict[str, typing.Any]]] = None,
-        bundler_options: typing.Optional[typing.Union[projen.javascript.BundlerOptions, typing.Dict[str, typing.Any]]] = None,
+        build_workflow_triggers: typing.Optional[typing.Union[_projen_github_workflows_04054675.Triggers, typing.Dict[builtins.str, typing.Any]]] = None,
+        bundler_options: typing.Optional[typing.Union[_projen_javascript_04054675.BundlerOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         code_cov: typing.Optional[builtins.bool] = None,
         code_cov_token_secret: typing.Optional[builtins.str] = None,
         copyright_owner: typing.Optional[builtins.str] = None,
         copyright_period: typing.Optional[builtins.str] = None,
         dependabot: typing.Optional[builtins.bool] = None,
-        dependabot_options: typing.Optional[typing.Union[projen.github.DependabotOptions, typing.Dict[str, typing.Any]]] = None,
+        dependabot_options: typing.Optional[typing.Union[_projen_github_04054675.DependabotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         deps_upgrade: typing.Optional[builtins.bool] = None,
-        deps_upgrade_options: typing.Optional[typing.Union[projen.javascript.UpgradeDependenciesOptions, typing.Dict[str, typing.Any]]] = None,
+        deps_upgrade_options: typing.Optional[typing.Union[_projen_javascript_04054675.UpgradeDependenciesOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         gitignore: typing.Optional[typing.Sequence[builtins.str]] = None,
         jest: typing.Optional[builtins.bool] = None,
-        jest_options: typing.Optional[typing.Union[projen.javascript.JestOptions, typing.Dict[str, typing.Any]]] = None,
+        jest_options: typing.Optional[typing.Union[_projen_javascript_04054675.JestOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         mutable_build: typing.Optional[builtins.bool] = None,
         npmignore: typing.Optional[typing.Sequence[builtins.str]] = None,
         npmignore_enabled: typing.Optional[builtins.bool] = None,
         package: typing.Optional[builtins.bool] = None,
         prettier: typing.Optional[builtins.bool] = None,
-        prettier_options: typing.Optional[typing.Union[projen.javascript.PrettierOptions, typing.Dict[str, typing.Any]]] = None,
+        prettier_options: typing.Optional[typing.Union[_projen_javascript_04054675.PrettierOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         projen_dev_dependency: typing.Optional[builtins.bool] = None,
         projenrc_js: typing.Optional[builtins.bool] = None,
-        projenrc_js_options: typing.Optional[typing.Union[projen.javascript.ProjenrcOptions, typing.Dict[str, typing.Any]]] = None,
+        projenrc_js_options: typing.Optional[typing.Union[_projen_javascript_04054675.ProjenrcOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         projen_version: typing.Optional[builtins.str] = None,
         pull_request_template: typing.Optional[builtins.bool] = None,
         pull_request_template_contents: typing.Optional[typing.Sequence[builtins.str]] = None,
         release: typing.Optional[builtins.bool] = None,
         release_to_npm: typing.Optional[builtins.bool] = None,
         release_workflow: typing.Optional[builtins.bool] = None,
-        workflow_bootstrap_steps: typing.Optional[typing.Sequence[typing.Union[projen.github.workflows.JobStep, typing.Dict[str, typing.Any]]]] = None,
-        workflow_git_identity: typing.Optional[typing.Union[projen.github.GitIdentity, typing.Dict[str, typing.Any]]] = None,
+        workflow_bootstrap_steps: typing.Optional[typing.Sequence[typing.Union[_projen_github_workflows_04054675.JobStep, typing.Dict[builtins.str, typing.Any]]]] = None,
+        workflow_git_identity: typing.Optional[typing.Union[_projen_github_04054675.GitIdentity, typing.Dict[builtins.str, typing.Any]]] = None,
         workflow_node_version: typing.Optional[builtins.str] = None,
-        auto_approve_options: typing.Optional[typing.Union[projen.github.AutoApproveOptions, typing.Dict[str, typing.Any]]] = None,
+        auto_approve_options: typing.Optional[typing.Union[_projen_github_04054675.AutoApproveOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         auto_merge: typing.Optional[builtins.bool] = None,
-        auto_merge_options: typing.Optional[typing.Union[projen.github.AutoMergeOptions, typing.Dict[str, typing.Any]]] = None,
+        auto_merge_options: typing.Optional[typing.Union[_projen_github_04054675.AutoMergeOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         clobber: typing.Optional[builtins.bool] = None,
         dev_container: typing.Optional[builtins.bool] = None,
         github: typing.Optional[builtins.bool] = None,
-        github_options: typing.Optional[typing.Union[projen.github.GitHubOptions, typing.Dict[str, typing.Any]]] = None,
+        github_options: typing.Optional[typing.Union[_projen_github_04054675.GitHubOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         gitpod: typing.Optional[builtins.bool] = None,
         mergify: typing.Optional[builtins.bool] = None,
-        mergify_options: typing.Optional[typing.Union[projen.github.MergifyOptions, typing.Dict[str, typing.Any]]] = None,
-        project_type: typing.Optional[projen.ProjectType] = None,
-        projen_credentials: typing.Optional[projen.github.GithubCredentials] = None,
+        mergify_options: typing.Optional[typing.Union[_projen_github_04054675.MergifyOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        project_type: typing.Optional[_projen_04054675.ProjectType] = None,
+        projen_credentials: typing.Optional[_projen_github_04054675.GithubCredentials] = None,
         projen_token_secret: typing.Optional[builtins.str] = None,
-        readme: typing.Optional[typing.Union[projen.SampleReadmeProps, typing.Dict[str, typing.Any]]] = None,
+        readme: typing.Optional[typing.Union[_projen_04054675.SampleReadmeProps, typing.Dict[builtins.str, typing.Any]]] = None,
         stale: typing.Optional[builtins.bool] = None,
-        stale_options: typing.Optional[typing.Union[projen.github.StaleOptions, typing.Dict[str, typing.Any]]] = None,
+        stale_options: typing.Optional[typing.Union[_projen_github_04054675.StaleOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         vscode: typing.Optional[builtins.bool] = None,
         allow_library_dependencies: typing.Optional[builtins.bool] = None,
         author_email: typing.Optional[builtins.str] = None,
@@ -183,7 +183,7 @@ class AwsCdkConstructLibrary(
         bugs_email: typing.Optional[builtins.str] = None,
         bugs_url: typing.Optional[builtins.str] = None,
         bundled_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
-        code_artifact_options: typing.Optional[typing.Union[projen.javascript.CodeArtifactOptions, typing.Dict[str, typing.Any]]] = None,
+        code_artifact_options: typing.Optional[typing.Union[_projen_javascript_04054675.CodeArtifactOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         deps: typing.Optional[typing.Sequence[builtins.str]] = None,
         description: typing.Optional[builtins.str] = None,
         dev_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -194,49 +194,49 @@ class AwsCdkConstructLibrary(
         licensed: typing.Optional[builtins.bool] = None,
         max_node_version: typing.Optional[builtins.str] = None,
         min_node_version: typing.Optional[builtins.str] = None,
-        npm_access: typing.Optional[projen.javascript.NpmAccess] = None,
+        npm_access: typing.Optional[_projen_javascript_04054675.NpmAccess] = None,
         npm_registry: typing.Optional[builtins.str] = None,
         npm_registry_url: typing.Optional[builtins.str] = None,
         npm_token_secret: typing.Optional[builtins.str] = None,
-        package_manager: typing.Optional[projen.javascript.NodePackageManager] = None,
+        package_manager: typing.Optional[_projen_javascript_04054675.NodePackageManager] = None,
         package_name: typing.Optional[builtins.str] = None,
-        peer_dependency_options: typing.Optional[typing.Union[projen.javascript.PeerDependencyOptions, typing.Dict[str, typing.Any]]] = None,
+        peer_dependency_options: typing.Optional[typing.Union[_projen_javascript_04054675.PeerDependencyOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         peer_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
         repository: typing.Optional[builtins.str] = None,
         repository_directory: typing.Optional[builtins.str] = None,
-        scoped_packages_options: typing.Optional[typing.Sequence[typing.Union[projen.javascript.ScopedPackagesOptions, typing.Dict[str, typing.Any]]]] = None,
+        scoped_packages_options: typing.Optional[typing.Sequence[typing.Union[_projen_javascript_04054675.ScopedPackagesOptions, typing.Dict[builtins.str, typing.Any]]]] = None,
         scripts: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         stability: typing.Optional[builtins.str] = None,
         jsii_release_version: typing.Optional[builtins.str] = None,
         major_version: typing.Optional[jsii.Number] = None,
         min_major_version: typing.Optional[jsii.Number] = None,
         npm_dist_tag: typing.Optional[builtins.str] = None,
-        post_build_steps: typing.Optional[typing.Sequence[typing.Union[projen.github.workflows.JobStep, typing.Dict[str, typing.Any]]]] = None,
+        post_build_steps: typing.Optional[typing.Sequence[typing.Union[_projen_github_workflows_04054675.JobStep, typing.Dict[builtins.str, typing.Any]]]] = None,
         prerelease: typing.Optional[builtins.str] = None,
         publish_dry_run: typing.Optional[builtins.bool] = None,
         publish_tasks: typing.Optional[builtins.bool] = None,
-        release_branches: typing.Optional[typing.Mapping[builtins.str, typing.Union[projen.release.BranchOptions, typing.Dict[str, typing.Any]]]] = None,
+        release_branches: typing.Optional[typing.Mapping[builtins.str, typing.Union[_projen_release_04054675.BranchOptions, typing.Dict[builtins.str, typing.Any]]]] = None,
         release_every_commit: typing.Optional[builtins.bool] = None,
         release_failure_issue: typing.Optional[builtins.bool] = None,
         release_failure_issue_label: typing.Optional[builtins.str] = None,
         release_schedule: typing.Optional[builtins.str] = None,
         release_tag_prefix: typing.Optional[builtins.str] = None,
-        release_trigger: typing.Optional[projen.release.ReleaseTrigger] = None,
+        release_trigger: typing.Optional[_projen_release_04054675.ReleaseTrigger] = None,
         release_workflow_name: typing.Optional[builtins.str] = None,
-        release_workflow_setup_steps: typing.Optional[typing.Sequence[typing.Union[projen.github.workflows.JobStep, typing.Dict[str, typing.Any]]]] = None,
+        release_workflow_setup_steps: typing.Optional[typing.Sequence[typing.Union[_projen_github_workflows_04054675.JobStep, typing.Dict[builtins.str, typing.Any]]]] = None,
         versionrc_options: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         workflow_container_image: typing.Optional[builtins.str] = None,
         workflow_runs_on: typing.Optional[typing.Sequence[builtins.str]] = None,
         name: builtins.str,
         commit_generated: typing.Optional[builtins.bool] = None,
-        logging: typing.Optional[typing.Union[projen.LoggerOptions, typing.Dict[str, typing.Any]]] = None,
+        logging: typing.Optional[typing.Union[_projen_04054675.LoggerOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         outdir: typing.Optional[builtins.str] = None,
-        parent: typing.Optional[projen.Project] = None,
+        parent: typing.Optional[_projen_04054675.Project] = None,
         projen_command: typing.Optional[builtins.str] = None,
         projenrc_json: typing.Optional[builtins.bool] = None,
-        projenrc_json_options: typing.Optional[typing.Union[projen.ProjenrcOptions, typing.Dict[str, typing.Any]]] = None,
+        projenrc_json_options: typing.Optional[typing.Union[_projen_04054675.ProjenrcOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         renovatebot: typing.Optional[builtins.bool] = None,
-        renovatebot_options: typing.Optional[typing.Union[projen.RenovatebotOptions, typing.Dict[str, typing.Any]]] = None,
+        renovatebot_options: typing.Optional[typing.Union[_projen_04054675.RenovatebotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param edge_lambda_auto_discover: (experimental) Automatically adds an ``cloudfront.experimental.EdgeFunction`` for each ``.edge-lambda.ts`` handler in your source tree. If this is disabled, you can manually add an ``awscdk.AutoDiscover`` component to your project. Default: true
@@ -403,7 +403,7 @@ class AwsCdkConstructLibrary(
 
         :stability: experimental
         '''
-        options = projen.awscdk.AwsCdkConstructLibraryOptions(
+        options = _projen_awscdk_04054675.AwsCdkConstructLibraryOptions(
             edge_lambda_auto_discover=edge_lambda_auto_discover,
             integration_test_auto_discover=integration_test_auto_discover,
             lambda_auto_discover=lambda_auto_discover,
@@ -571,9 +571,9 @@ class AwsCdkConstructLibrary(
 
     @builtins.property
     @jsii.member(jsii_name="formatTask")
-    def format_task(self) -> projen.Task:
+    def format_task(self) -> _projen_04054675.Task:
         '''The "format" task.'''
-        return typing.cast(projen.Task, jsii.get(self, "formatTask"))
+        return typing.cast(_projen_04054675.Task, jsii.get(self, "formatTask"))
 
 
 __all__ = [
